@@ -1,6 +1,6 @@
 package FusionInventory::Agent::Task::OcsDeploy;
 use threads;
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 # TODO
 # TIMEOUT="30" number of retry to do on a download
 # CYCLE_LATENCY="60" time to wait between each different priority processing
@@ -58,8 +58,10 @@ sub main {
             }
         });
 
-    my $data = $storage->restore("FusionInventory::Agent");
-    my $myData = $self->{myData} = $storage->restore(__PACKAGE__);
+    my $data = $storage->restore({
+            module => "FusionInventory::Agent"
+        });
+    my $myData = $self->{myData} = $storage->restore();
 
     my $config = $self->{config} = $data->{config};
     my $target = $self->{'target'} = $data->{'target'};
@@ -180,7 +182,7 @@ sub main {
     }
 
 
-    $storage->save($myData);
+    $storage->save({ data => $myData });
 
     exit(0);
 }
